"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShardMetadata = exports.Shard = exports.Outcomes = exports.Outcome = exports.LocalMetadata = exports.ExecutionSummary = exports.Calls = exports.Call = exports.BlockSummary = exports.Block = void 0;
Object.defineProperty(exports, "baseDecode", {
  enumerable: true,
  get: function () {
    return _borsh.baseDecode;
  }
});
Object.defineProperty(exports, "baseEncode", {
  enumerable: true,
  get: function () {
    return _borsh.baseEncode;
  }
});
exports.shardSchema = exports.shardMetadataSchema = exports.parseShardMetadata = exports.parseShard = exports.parseOutcomes = exports.parseOutcome = exports.parseLocalMetadata = exports.parseExecutionSummary = exports.parseCalls = exports.parseCall = exports.parseBlockSummary = exports.parseBlock = exports.outcomesSchema = exports.outcomeSchema = exports.localMetadataSchema = exports.executionSummarySchema = exports.callsSchema = exports.callSchema = exports.buildShardMetadata = exports.buildShard = exports.buildOutcomes = exports.buildOutcome = exports.buildLocalMetadata = exports.buildExecutionSummary = exports.buildCalls = exports.buildCall = exports.buildBlockSummary = exports.buildBlock = exports.blockSummarySchema = exports.blockSchema = void 0;
var _borsh = require("borsh");
// Copyright 2021-2022 @skyekiwi/s-contract authors & contributors
// SPDX-License-Identifier: Apache-2.0

/* eslint-disable sort-keys, camelcase */
class Call {
  // public transaction_action: 'create_account' | 'call' | 'transfer' | 'view_method_call' | 'deploy'

  constructor(config) {
    this.origin_public_key = void 0;
    this.receipt_public_key = void 0;
    this.encrypted_egress = void 0;
    this.transaction_action = void 0;
    this.amount = void 0;
    this.contract_name = void 0;
    this.method = void 0;
    this.args = void 0;
    this.wasm_code = void 0;
    this.origin_public_key = config.origin_public_key;
    this.receipt_public_key = config.receipt_public_key;
    this.encrypted_egress = config.encrypted_egress;
    this.transaction_action = config.transaction_action;
    this.amount = config.amount;
    this.contract_name = config.contract_name;
    this.method = config.method;
    this.args = config.args;
    this.wasm_code = config.wasm_code;
  }
}
exports.Call = Call;
class Calls {
  constructor(config) {
    this.ops = void 0;
    this.shard_id = void 0;
    this.block_number = void 0;
    this.ops = config.ops;
    this.shard_id = config.shard_id;
    this.block_number = config.block_number;
  }
}
exports.Calls = Calls;
class Outcome {
  constructor(config) {
    this.view_result_log = void 0;
    this.view_result = void 0;
    this.view_error = void 0;
    this.outcome_logs = void 0;
    this.outcome_token_burnt = void 0;
    this.outcome_status = void 0;
    this.view_result_log = config.view_result_log;
    this.view_result = config.view_result;
    this.view_error = config.view_error;
    this.outcome_logs = config.outcome_logs;
    this.outcome_token_burnt = config.outcome_token_burnt;
    this.outcome_status = config.outcome_status;
  }
}
exports.Outcome = Outcome;
class Outcomes {
  constructor(config) {
    this.ops = void 0;
    this.call_ids = void 0;
    this.signatures = void 0;
    this.state_root = void 0;
    this.ops = config.ops;
    this.call_ids = config.call_ids;
    this.signatures = config.signatures;
    this.state_root = config.state_root;
  }
}
exports.Outcomes = Outcomes;
class LocalMetadata {
  constructor(config) {
    this.shard_id = void 0;
    this.high_local_block = void 0;
    this.shard_id = config.shard_id;
    this.high_local_block = config.high_local_block;
  }
}
exports.LocalMetadata = LocalMetadata;
class Block {
  constructor(config) {
    this.shard_id = void 0;
    this.block_number = void 0;
    this.calls = void 0;
    this.shard_id = config.shard_id;
    this.block_number = config.block_number;
    this.calls = config.calls;
  }
}
exports.Block = Block;
class Shard {
  constructor(config) {
    this.high_remote_synced_block_index = void 0;
    this.high_remote_confirmed_block_index = void 0;
    this.high_remote_synced_block_index = config.high_remote_synced_block_index;
    this.high_remote_confirmed_block_index = config.high_remote_confirmed_block_index;
  }
}
exports.Shard = Shard;
class ShardMetadata {
  constructor(config) {
    this.shard_key = void 0;
    this.shard_members = void 0;
    this.beacon_index = void 0;
    this.threshold = void 0;
    this.shard_key = config.shard_key;
    this.shard_members = config.shard_members;
    this.beacon_index = config.beacon_index;
    this.threshold = config.threshold;
  }
}
exports.ShardMetadata = ShardMetadata;
class ExecutionSummary {
  constructor(config) {
    this.high_local_execution_block = void 0;
    this.latest_state_root = void 0;
    this.high_local_execution_block = config.high_local_execution_block;
    this.latest_state_root = config.latest_state_root;
  }
}
exports.ExecutionSummary = ExecutionSummary;
class BlockSummary {
  constructor(config) {
    this.block_number = void 0;
    this.block_state_root = void 0;
    this.contract_state_patch_from_previous_block = void 0;
    this.call_state_patch_from_previous_block = void 0;
    this.block_number = config.block_number;
    this.block_state_root = config.block_state_root;
    this.contract_state_patch_from_previous_block = config.contract_state_patch_from_previous_block;
    this.call_state_patch_from_previous_block = config.call_state_patch_from_previous_block;
  }
}
exports.BlockSummary = BlockSummary;
const blockSummarySchema = new Map([[BlockSummary, {
  kind: 'struct',
  fields: [['block_number', 'u32'], ['block_state_root', ['u8', 32]], ['contract_state_patch_from_previous_block', ['u8']], ['call_state_patch_from_previous_block', ['u8']]]
}]]);
exports.blockSummarySchema = blockSummarySchema;
const blockSchema = new Map([[Block, {
  kind: 'struct',
  fields: [['shard_id', 'u32'], ['block_number', 'u32'], ['calls', {
    kind: 'option',
    type: ['u32']
  }]]
}]]);
exports.blockSchema = blockSchema;
const callSchema = new Map([[Call, {
  kind: 'struct',
  fields: [['origin_public_key', ['u8', 32]], ['receipt_public_key', ['u8', 32]], ['encrypted_egress', 'u8'], ['transaction_action', 'u8'], ['amount', {
    kind: 'option',
    type: 'u32'
  }], ['contract_name', {
    kind: 'option',
    type: ['u8']
  }], ['method', {
    kind: 'option',
    type: ['u8']
  }], ['args', {
    kind: 'option',
    type: ['u8']
  }], ['wasm_code', {
    kind: 'option',
    type: ['u8']
  }]]
}]]);
exports.callSchema = callSchema;
const callsSchema = new Map();
exports.callsSchema = callsSchema;
callsSchema.set(Calls, {
  kind: 'struct',
  fields: [['ops', [Call]], ['shard_id', 'u32'], ['block_number', {
    kind: 'option',
    type: 'u32'
  }]]
});
callsSchema.set(Call, callSchema.get(Call));
const outcomeSchema = new Map([[Outcome, {
  kind: 'struct',
  fields: [['view_result_log', [['u8']]], ['view_result', {
    kind: 'option',
    type: ['u8']
  }], ['view_error', {
    kind: 'option',
    type: ['u8']
  }], ['outcome_logs', [['u8']]], ['outcome_token_burnt', 'u32'], ['outcome_status', {
    kind: 'option',
    type: ['u8']
  }]]
}]]);
exports.outcomeSchema = outcomeSchema;
const outcomesSchema = new Map();
exports.outcomesSchema = outcomesSchema;
outcomesSchema.set(Outcomes, {
  kind: 'struct',
  fields: [['ops', [Outcome]], ['call_ids', ['u32']], ['signatures', [['u8']]], ['state_root', ['u8', 32]]]
});
outcomesSchema.set(Outcome, outcomeSchema.get(Outcome));
const shardMetadataSchema = new Map([[ShardMetadata, {
  kind: 'struct',
  fields: [['shard_key', ['u8', 32]], ['shard_members', ['string']], ['beacon_index', 'u32'], ['threshold', 'u32']]
}]]);
exports.shardMetadataSchema = shardMetadataSchema;
const shardSchema = new Map([[Shard, {
  kind: 'struct',
  fields: [['high_remote_synced_block_index', 'u32'], ['high_remote_confirmed_block_index', 'u32']]
}]]);
exports.shardSchema = shardSchema;
const localMetadataSchema = new Map([[LocalMetadata, {
  kind: 'struct',
  fields: [['shard_id', ['u32']], ['high_local_block', 'u32']]
}]]);
exports.localMetadataSchema = localMetadataSchema;
const executionSummarySchema = new Map([[ExecutionSummary, {
  kind: 'struct',
  fields: [['high_local_execution_block', 'u32'], ['latest_state_root', ['u8', 32]]]
}]]);

// ser
exports.executionSummarySchema = executionSummarySchema;
const buildCall = call => {
  const buf = (0, _borsh.serialize)(callSchema, call);
  return (0, _borsh.baseEncode)(buf);
};
exports.buildCall = buildCall;
const buildBlock = block => {
  const buf = (0, _borsh.serialize)(blockSchema, block);
  return (0, _borsh.baseEncode)(buf);
};
exports.buildBlock = buildBlock;
const buildCalls = calls => {
  const buf = (0, _borsh.serialize)(callsSchema, calls);
  return (0, _borsh.baseEncode)(buf);
};
exports.buildCalls = buildCalls;
const buildOutcome = outcome => {
  const buf = (0, _borsh.serialize)(outcomeSchema, outcome);
  return (0, _borsh.baseEncode)(buf);
};
exports.buildOutcome = buildOutcome;
const buildOutcomes = outcomes => {
  const buf = (0, _borsh.serialize)(outcomesSchema, outcomes);
  return (0, _borsh.baseEncode)(buf);
};
exports.buildOutcomes = buildOutcomes;
const buildShard = shard => {
  const buf = (0, _borsh.serialize)(shardSchema, shard);
  return (0, _borsh.baseEncode)(buf);
};
exports.buildShard = buildShard;
const buildShardMetadata = shardMetadata => {
  const buf = (0, _borsh.serialize)(shardMetadataSchema, shardMetadata);
  return (0, _borsh.baseEncode)(buf);
};
exports.buildShardMetadata = buildShardMetadata;
const buildLocalMetadata = a => {
  const buf = (0, _borsh.serialize)(localMetadataSchema, a);
  return (0, _borsh.baseEncode)(buf);
};
exports.buildLocalMetadata = buildLocalMetadata;
const buildExecutionSummary = a => {
  const buf = (0, _borsh.serialize)(executionSummarySchema, a);
  return (0, _borsh.baseEncode)(buf);
};
exports.buildExecutionSummary = buildExecutionSummary;
const buildBlockSummary = a => {
  const buf = (0, _borsh.serialize)(blockSummarySchema, a);
  return (0, _borsh.baseEncode)(buf);
};

// de
exports.buildBlockSummary = buildBlockSummary;
const parseCall = buf => {
  const c = (0, _borsh.deserialize)(callSchema, Call, (0, _borsh.baseDecode)(buf));
  c.encrypted_egress = !!c.encrypted_egress;
  return c;
};
exports.parseCall = parseCall;
const parseCalls = buf => {
  const cs = (0, _borsh.deserialize)(callsSchema, Calls, (0, _borsh.baseDecode)(buf));
  for (let i = 0; i < cs.ops.length; i++) {
    cs.ops[i].encrypted_egress = !!cs.ops[i].encrypted_egress;
  }
  return cs;
};
exports.parseCalls = parseCalls;
const parseOutcome = buf => {
  return (0, _borsh.deserialize)(outcomeSchema, Outcome, (0, _borsh.baseDecode)(buf));
};
exports.parseOutcome = parseOutcome;
const parseOutcomes = buf => {
  return (0, _borsh.deserialize)(outcomesSchema, Outcomes, (0, _borsh.baseDecode)(buf));
};
exports.parseOutcomes = parseOutcomes;
const parseBlock = buf => {
  return (0, _borsh.deserialize)(blockSchema, Block, (0, _borsh.baseDecode)(buf));
};
exports.parseBlock = parseBlock;
const parseShard = buf => {
  return (0, _borsh.deserialize)(shardSchema, Shard, (0, _borsh.baseDecode)(buf));
};
exports.parseShard = parseShard;
const parseShardMetadata = buf => {
  return (0, _borsh.deserialize)(shardMetadataSchema, ShardMetadata, (0, _borsh.baseDecode)(buf));
};
exports.parseShardMetadata = parseShardMetadata;
const parseLocalMetadata = buf => {
  return (0, _borsh.deserialize)(localMetadataSchema, LocalMetadata, (0, _borsh.baseDecode)(buf));
};
exports.parseLocalMetadata = parseLocalMetadata;
const parseExecutionSummary = buf => {
  return (0, _borsh.deserialize)(executionSummarySchema, ExecutionSummary, (0, _borsh.baseDecode)(buf));
};
exports.parseExecutionSummary = parseExecutionSummary;
const parseBlockSummary = buf => {
  return (0, _borsh.deserialize)(blockSummarySchema, BlockSummary, (0, _borsh.baseDecode)(buf));
};
exports.parseBlockSummary = parseBlockSummary;